@@ -15,4 +15,8 @@ def get_location():
        
 def alert(msg):
     print(msg)
-    messagebox.showinfo('Error', msg)
\ No newline at end of file
+    messagebox.showinfo('Error', msg)
+    
+def tips(msg):
+    print(msg)
+    messagebox.showinfo('Quick Tips', msg)
\ No newline at end of file
